/**
 * VerfahrensDatenContainer2GUI.java
 * eu.gronos.kostenrechner (Kostenrechner)
 */
package eu.gronos.kostenrechner.controller.files;

import java.io.File;

import eu.gronos.kostenrechner.Kostenrechner;
import eu.gronos.kostenrechner.model.tenordaten.VerfahrensDatenContainer;
import eu.gronos.kostenrechner.view.AktionenJMenu;
import eu.gronos.kostenrechner.view.baumbach.StreitgenossenPanel;
import eu.gronos.kostenrechner.view.forderungen.ForderungsStaffelungPanel;
import eu.gronos.kostenrechner.view.gebuehren.GebuehrenBerechnungPanel;
import eu.gronos.kostenrechner.view.gebuehren.TeilklageruecknahmePanel;

/**
 * Die Klasse stellt Methoden bereit, um die Werte einem
 * {@link VerfahrensDatenContainer} in die einzelnen JPanels zu schreiben, um
 * umgekehrt die Werte aus den JPanels in einen {@link VerfahrensDatenContainer}
 * zu schreiben und auch, um diese Werte aus einer XML-Datei zu nehmen.
 *
 * @author Peter Schuster (setrok)
 * @date 06.09.2018
 *
 */
public class VerfahrensDatenContainer2GUI {

	/**
	 * Die Methode dient dazu, alle Programmzustände dem
	 * {@link VerfahrensDatenContainer} anzupassen.
	 * 
	 * @param container ein {@link VerfahrensDatenContainer}
	 */
	void setzeAlleWerteAusContainer(VerfahrensDatenContainer container) {
		Kostenrechner.getLogger().info(VerfahrensDatenContainerUtil.allgemeinContainerToString(container));

		/* Allgemeine Einstellungen */
		AktionenJMenu.getInstance().setzeWerte(container.allgemein);

		/* Erste Registerkarte Teilklagerücknahme */
		TeilklageruecknahmePanel.getInstance().setzeWerte(container.teilklageruecknahme);

		/* Zweite Registerkarte Streitgenossen */
		StreitgenossenPanel.getInstance().setzeWerte(container.streitgenossen);

		/* Dritte Registerkarte Forderungsstaffelung */
		ForderungsStaffelungPanel.getInstance().setzeWerte(container.staffelung);

		/* Vierte Registerkarte Freie Gebührenberechnung */
		GebuehrenBerechnungPanel.getInstance().setzeWerte(container.gebuehrenBerechnung);

	}

	/**
	 * Die Methode dient dazu, alle Programmzustände in einen
	 * {@link VerfahrensDatenContainer} zu packen
	 * 
	 * @return einen {@link VerfahrensDatenContainer}
	 */
	public VerfahrensDatenContainer leseAlleWertefuerContainer() {
		VerfahrensDatenContainer container = new VerfahrensDatenContainer();

		/*
		 * Allgemeine Programmeinstellungen, die nicht vom Container selbst gesetzt
		 * werden
		 */
		container.allgemein = AktionenJMenu.getInstance().baueRueckgabewert();

		/* Erste Registerkarte Teilklagerücknahme */
		container.teilklageruecknahme = TeilklageruecknahmePanel.getInstance().baueRueckgabewert();

		/* Zweite Registerkarte Streitgenossen */
		container.streitgenossen = StreitgenossenPanel.getInstance().baueRueckgabewert();

		/* Dritte Registerkarte Forderungsstaffelung */
		container.staffelung = ForderungsStaffelungPanel.getInstance().baueRueckgabewert();

		/* Vierte Registerkarte Freie Gebührenberechnung */
		container.gebuehrenBerechnung = GebuehrenBerechnungPanel.getInstance().baueRueckgabewert();

		/* Höchster Wert im Verfahren */
		VerfahrensDatenContainerUtil.setzeAllgemeinStreitwert(container);

		/* und weg damit */
		return container;
	}

	/**
	 * Die Methode dient zum Xjustiz-Import bzw Laden von Xml-Berechnungen aus
	 * {@link Kostenrechner#main(String[]) main} und aus anderen Klassen.
	 * 
	 * Wenn <code>null</code> übergeben wird, macht sie einfach nix.
	 * 
	 * @param xml ein {@link File}
	 */
	public void nimmXmlDatei(File xml) {
		VerfahrensDatenContainer container = null;
		if (xml != null) {
			Kostenrechner.getLogger().info("nimmXmlDatei");
			if (XmlTransferHandler.isXml(xml))
				container = new LadeXjustizController(StreitgenossenPanel.getInstance(), Kostenrechner.getInstance())
						.xJustizLesen(xml);
			else if (XmlTransferHandler.isBerechnung(xml))
				container = new BerechnungXmlDatei().ladeXml(xml);
			if (container != null)
				setzeAlleWerteAusContainer(container);
		}
	}

}
