/**
 * CopyrightNoergler.java
 * eu.gronos.kostenrechner.controller.system (Kostenrechner)
 */
package eu.gronos.kostenrechner.controller.system;

import javax.swing.JFrame;

import eu.gronos.kostenrechner.interfaces.Noergelnd;
import eu.gronos.kostenrechner.view.helpanderror.DatenschutzAkzeptanzDialog;

/**
 * Wenn der Datenschutzhinweis noch nicht akzeptiert wurde, dann nörgeln. Wenn
 * nicht akzeptiert wird, dann aufhören. Sonst Vermerk in Registry/Preferences
 * und weiter.
 *
 * @author Peter Schuster (setrok)
 * @date 21 Feb 2019
 *
 */
public class DatenschutzNoergler implements Noergelnd<BooleanConfigOption> {

	private final JFrame owner;
	private final BooleanConfigOption option;// = new StringConfigOption("lizenz", "");
	private int index;
	public static final int OPTION_DSGVO_EMAIL_BASIS = 21;
	public static final int OPTION_DSGVO_EMAIL_ANHANG = 34;

	/**
	 * @param owner  ein {@link JFrame}
	 * @param index  entweder {@link #OPTION_DSGVO_EMAIL_BASIS} oder
	 *               {@link #OPTION_DSGVO_EMAIL_ANHANG}
	 */
	public DatenschutzNoergler(JFrame owner, int index) {
		this.owner = owner;
		this.index = index;
		if (OPTION_DSGVO_EMAIL_ANHANG == index)
			option = new BooleanConfigOption("dsgvo-email-anhang", false);
		else
			option = new BooleanConfigOption("dsgvo-email-basis", false);
	}

	/**
	 * Wenn der Datenschutzhinweis schon akzeptiert wurde, dann <code>true</code>.
	 * Sonst nörgeln. Wenn nicht akzeptiert wird, dann <code>false</code>
	 * zurückgeben. Sonst Vermerk in Registry/Preferences und <code>true</code>
	 * zurückgeben.
	 * 
	 * @return <code>true</code>, wenn bereits zuvor akzeptiert oder nach
	 *         Aufforderung akzeptiert. Sonst false
	 * 
	 * @see eu.gronos.kostenrechner.interfaces.Noergelnd#noergle()
	 */
	@Override
	public boolean noergle() {
		if (getOption().getValue()) {
			// Laut Registry schon akzeptiert
			return true;
		} else {
			// noch nicht akzeptiert: Benutzer fragen
			final DatenschutzAkzeptanzDialog dialog = new DatenschutzAkzeptanzDialog(owner, index);
			boolean akzeptiert = false;
			final Boolean wert = dialog.showDialog();
			if (wert != null)
				akzeptiert = wert.booleanValue();
			if (akzeptiert) {
				getOption().setValue(true);
				return true;
			} else {
				return false;
			}
		}
	}

	/**
	 * Für das Speichern in der Registry oder den Preferences nötige Felder
	 * 
	 * @return gibt {@link option} als {@link BooleanConfigOptionHorcher} zurück.
	 * 
	 * @see eu.gronos.kostenrechner.interfaces.Noergelnd#getOption()
	 */
	@Override
	public BooleanConfigOption getOption() {
		return option;
	}
	
	/**
	 * Die Methode setzt wieder den Standardwert der {@link #getOption()} in die Registry/Preferences.
	 */
	public void reset() {
		getOption().reset();
	}
}
