/*
 * Vorsorgend.java
 * eu.gronos.kostenrechner.model (Kostenrechner)
 */
package eu.gronos.kostenrechner.interfaces;

import java.util.List;

import javax.swing.JComponent;

import eu.gronos.kostenrechner.model.Beschriftung;
import eu.gronos.kostenrechner.model.LangVorsorgeBeschriftung;
import eu.gronos.kostenrechner.model.VorsorgendeBeschriftung;

/**
 * Interface für die gemeinsamen Methoden von {@link VorsorgendeBeschriftung}
 * und {@link LangVorsorgeBeschriftung}
 *
 * @author Peter Schuster (setrok)
 * @date 05.10.2019
 *
 * @param E die von {@link Beschriftung} abgeleitete Klasse, die das
 *               Interface implementiert, also {@link VorsorgendeBeschriftung}
 *               oder {@link LangVorsorgeBeschriftung}
 */
public interface Vorsorgend<E extends Beschriftung> {

	/**
	 * @return gibt {@link #alternativeTitles} als {@link List<String>} zurück. Das
	 *         ist eine vorsorgend bereitgehaltene Liste anderer Titel, die die
	 *         {@link JComponent} in anderen Zuständen tragen kann.
	 */
	List<String> getAlternativeTitles();

	/**
	 * @param alternativeTitles d. {@link #alternativeTitles}, d. gesetzt werden
	 *                          soll als {@link List<String>}.
	 */
	void setAlternativeTitles(List<String> alternativeTitles);

	/**
	 * Die Methode setzt einen Title aus den vorhandenen
	 * {@link #getAlternativeTitles()}. Danach muss applyTo() aufgerufen werden.
	 * 
	 * @param index der Index des neuen Titles
	 * @return die {@link Beschriftung} mit dem neuen
	 *         {@link Beschriftung#getTitle()}
	 */
	E changeTo(int index);

}