/*
 * LangBeschriftung.java
 * eu.gronos.kostenrechner.model (Kostenrechner)
 */
package eu.gronos.kostenrechner.model;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.net.URL;

import javax.swing.AbstractButton;
import javax.swing.Action;
import javax.swing.ImageIcon;
import javax.swing.JComponent;
import javax.swing.JMenuItem;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;

/**
 * von Beschriftung abgeleitete Klasse „LangBeschriftung“ mit dem zusätzlichen
 * Feld String/Element longDescription (XmlElement) und ggfs URL img
 * (XmlAttribute). Nicht den Shortkey, auch nicht den AcceleratorKey, das ist
 * jeweils ein int und wäre bei einem Export dann nur noch eine Zahl (aber auch
 * zentral sammeln). JButton und Action haben dieselbe ID
 *
 * @author Peter Schuster (setrok)
 * @date 03.08.2019
 *
 */
public class LangBeschriftung extends Beschriftung {
	private static final long serialVersionUID = 2299722526230365280L;
	private String longDescription = null;
	private String actionCommandKey = null;
	private TastenKombination acceleratorKey = null;
	private String image;

	/**
	 * Die Methode wendet die Beschriftung auf eine {@link JComponent} an.
	 * 
	 * @param comp die {@link Component}
	 * @return dieselbe {@link Component}
	 * @throws IllegalArgumentException TODO
	 * 
	 * @see eu.gronos.kostenrechner.model.Beschriftung#applyTo(java.awt.Component)
	 */
	@Override
	public Component applyTo(Component comp) throws IllegalArgumentException {
		super.applyTo(comp);
		if (comp instanceof AbstractButton) {
			final AbstractButton button = (AbstractButton) comp;
			if (button.getAction() != null) {
				applyTo(button.getAction());
			} else {
				button.setActionCommand(getActionCommandKey());
				if (button instanceof JMenuItem && getAcceleratorKey() != null) {
					((JMenuItem) button).setAccelerator(getAcceleratorKey().toKeyStroke());
				}
			}
		}
		return comp;
	}

	/**
	 * Setzt die values der Action.
	 */
	public Action applyTo(Action action) {
		action.putValue(Action.NAME, super.getTitle());
		action.putValue(Action.SHORT_DESCRIPTION, super.getShortDescription());
		if (getLongDescription() != null)
			action.putValue(Action.LONG_DESCRIPTION, getLongDescription());
		if (getActionCommandKey() != null)
			action.putValue(Action.ACTION_COMMAND_KEY, getActionCommandKey());
		if (getImage() != null)
			action.putValue(Action.LARGE_ICON_KEY,
					new ImageIcon(getClass().getClassLoader().getResource(this.getImage())));
		if (hasMnemonic())// getMnemonic() != null
			action.putValue(Action.MNEMONIC_KEY, Integer.valueOf(mnemonicIntValue()));
		if (getAcceleratorKey() != null)
			action.putValue(Action.ACCELERATOR_KEY, getAcceleratorKey().toKeyStroke());
		return action;
	}
	// Beschriftung.baueHtmlTooltip(super.getTitle(), )

	/**
	 * The key used for storing a longer <code>String</code> description for the
	 * action, could be used for context-sensitive help.
	 * 
	 * @return gibt {@link #longDescription} als {@link String} zurück.
	 */
	@XmlElement
	public String getLongDescription() {
		return longDescription;
	}

	/**
	 * @param longDescription d. {@link #getLongDescription()}, d. gesetzt werden
	 *                        soll als {@link String}.
	 */
	public void setLongDescription(String longDescription) {
		this.longDescription = longDescription.trim().replaceAll("\\s+", " ");
	}

	/**
	 * 
	 * @return gibt {@link #actionCommandKey} als {@link String} zurück.
	 *         ({@link javax.swing.Action#ACTION_COMMAND_KEY}) The key used to
	 *         determine the command String for the {@link ActionEvent} that will be
	 *         created when an {@link Action} is going to be notified as the result
	 *         of residing in a Keymap associated with a {@link JComponent}.
	 */
	@XmlAttribute(name = "key")
	public String getActionCommandKey() {
		return actionCommandKey;
	}

	/**
	 * @param actionCommandKey d. {@link #getActionCommandKey()}, d. gesetzt werden
	 *                         soll als {@link String}.
	 */
	public void setActionCommandKey(String actionCommandKey) {
		this.actionCommandKey = actionCommandKey;
	}

	/**
	 * The key used for storing an <code>Icon</code>. This is typically used by
	 * buttons, such as <code>JButton</code> and <code>JToggleButton</code>.
	 * 
	 * @return gibt {@link #image} als {@link String} zurück, denn {@link URL} geht
	 *         nicht.
	 */
	@XmlAttribute(name = "img")
	public String getImage() {
		return image;
	}

	/**
	 * @param img d. {@link #image}, d. gesetzt werden soll als {@link URL}.
	 */
	public void setImage(String img) {
		this.image = img;
	}

	/**
	 * @return gibt {@link #acceleratorKey} als {@link TastenKombination} zurück.
	 */
	@XmlElement(name = "accelerator")
	public TastenKombination getAcceleratorKey() {
		return acceleratorKey;
	}

	/**
	 * @param acceleratorKey d. {@link #acceleratorKey}, d. gesetzt werden soll als
	 *                       {@link TastenKombination}.
	 */
	public void setAcceleratorKey(TastenKombination acceleratorKey) {
		this.acceleratorKey = acceleratorKey;
	}

	@Override
	public String toString() {
		return String.format(
				"LangBeschriftung [id()=%s, title()=%s, actionCommandKey=%s, shortDescription()=%s, longDescription=%s, image=%s]",
				getId(), getTitle(), actionCommandKey, getShortDescription(), longDescription, image);
	}

}
