/*
 * LangVorsorgeBeschriftung.java
 * eu.gronos.kostenrechner.model (Kostenrechner)
 */
package eu.gronos.kostenrechner.model;

import java.awt.Component;
import java.util.ArrayList;
import java.util.List;

import javax.swing.Action;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlElements;

import eu.gronos.kostenrechner.interfaces.Vorsorgend;

/**
 * Eine von {@link LangVorsorgeBeschriftung} abgeleitete Klasse mit einer
 * List<String> alternateTitles und auch alternateDescriptions für Elemente, die
 * ihre Beschriftung zwischendurch wechseln, vorsorgend weil es eine Reserve an
 * Strings hat
 * 
 * @author Peter Schuster (setrok)
 * @date 05.08.2019
 *
 */
public class LangVorsorgeBeschriftung extends LangBeschriftung implements Vorsorgend<LangVorsorgeBeschriftung> {
	private static final long serialVersionUID = -2627581964285739761L;
	/*
	 * Die Listen müssen je einmal angelegt werden, sonst hat der Unmarshaller
	 * Probleme
	 */
	private List<String> alternativeTitles = new ArrayList<String>();
	private List<String> alternativeDescriptions = new ArrayList<String>();

	/**
	 * Die Methode setzt einen {@link #getTitle()} aus den vorhandenen
	 * {@link #getAlternativeTitles()} und die {@link #getShortDescription()} aus
	 * den {@link #getAlternativeDescriptions()}. Danach muss applyTo() aufgerufen
	 * werden.
	 * 
	 * @param index der Index des neuen Titles
	 * @return die {@link LangVorsorgeBeschriftung} mit dem neuen
	 *         {@link Beschriftung#getTitle()} und der neuen
	 *         {@link Beschriftung#getShortDescription()}
	 * 
	 * @see eu.gronos.kostenrechner.interfaces.Vorsorgend#changeTo(int)
	 */
	public LangVorsorgeBeschriftung changeTo(int index) {
		if (index > -1 && index < getAlternativeTitles().size()) {
			super.setTitle(getAlternativeTitles().get(index));
		} else {
			System.err.printf("Titel aus Beschriftung nicht vorhanden: %d!%n", index);
		}
		if (index > -1 && getAlternativeDescriptions() != null && index < getAlternativeDescriptions().size()) {
			super.setShortDescription(getAlternativeDescriptions().get(index));
		} else {
			System.err.printf("Beschreibung aus Beschriftung nicht vorhanden: %d!%n", index);
		}
		return this;// super.getTitle();
	}

	/**
	 * 
	 * @return gibt {@link #alternativeTitles} als {@link List<String>} zurück. Das
	 *         ist eine vorsorgend bereitgehaltene Liste anderer Titel, die die
	 *         {@link Action} in anderen Zuständen tragen kann.
	 */
	@XmlElementWrapper(name = "alternativeTitles")
	@XmlElement(name = "alternativeTitle")
	public List<String> getAlternativeTitles() {
		return alternativeTitles;
	}

	/**
	 * @param alternativeTitles d. {@link #alternativeTitles}, d. gesetzt werden
	 *                          soll als {@link List<String>}.
	 */
	public void setAlternativeTitles(List<String> alternativeTitles) {
		this.alternativeTitles = new ArrayList<String>();// LinkedList
		// alternativeTitles;
		for (String title : alternativeTitles) {
			this.alternativeTitles.add(super.deWhiteSpace(title));
		}
	}

	/**
	 * @return gibt {@link #alternativeDescriptions} als {@link List<String>}
	 *         zurück. Das ist eine vorsorgend bereitgehaltene Liste anderer
	 *         Beschreibungen, die die {@link Action} in anderen Zuständen tragen
	 *         kann.
	 */
	@XmlElementWrapper(name = "alternativeDescriptions")
	@XmlElements({ @XmlElement(name = "alternativeDescription", type = String.class) })
	public List<String> getAlternativeDescriptions() {
		return alternativeDescriptions;
	}

	/**
	 * @param alternativeDescriptions d. {@link #getAlternativeDescriptions}, d.
	 *                                gesetzt werden soll als {@link List<String>}.
	 */
	public void setAlternativeDescriptions(List<String> alternativeDescriptions) {
		this.alternativeDescriptions = new ArrayList<String>();// LinkedList
		for (String description : alternativeDescriptions) {
			this.alternativeDescriptions.add(super.deWhiteSpace(description));
		}
	}

	@Override
	public Component applyTo(Component comp) throws IllegalArgumentException {
		// TODO Listeners?
		super.applyTo(comp);
		return comp;
	}
}
