/*
 * VorsorgendeBeschriftung.java
 * eu.gronos.kostenrechner.model (Kostenrechner)
 */
package eu.gronos.kostenrechner.model;

import java.awt.Component;
import java.util.ArrayList;
import java.util.List;

import javax.swing.JComponent;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementWrapper;
import javax.xml.bind.annotation.XmlElements;

import eu.gronos.kostenrechner.interfaces.Vorsorgend;

/**
 * von Beschriftung abgeleitete Klasse „VorsorgendeBeschriftung“ mit einer
 * List<String> alternateTitles (XmlElements/Wrapper) und vielleicht auch
 * alternateDescriptions (XmlElements/Wrapper?) für Elemente, die ihre
 * Beschriftung zwischendurch wechseln, vorsorgend weil es eine Reserve an
 * Strings hat, Wenn ein JLabel zwischendurch geändert wird, zweite Beschriftung
 * speichern, nein besser: Alternativen mitspeichern in VorsorgendeBeschriftung,
 * s.o.
 * 
 * @author Peter Schuster (setrok)
 * @date 03.08.2019
 *
 */
public class VorsorgendeBeschriftung extends Beschriftung implements Vorsorgend<VorsorgendeBeschriftung> {
	private static final long serialVersionUID = 7551783095558692578L;
	/* Die Liste muss einmal angelegt werden, sonst hat der Unmarshaller Probleme */
	private List<String> alternativeTitles = new ArrayList<String>();

	/**
	 * @return gibt {@link #alternativeTitles} als {@link List<String>} zurück. Das
	 *         ist eine vorsorgend bereitgehaltene Liste anderer Titel, die die
	 *         {@link JComponent} in anderen Zuständen tragen kann.
	 * @see eu.gronos.kostenrechner.interfaces.Vorsorgend#getAlternativeTitles()
	 */
	@Override
	@XmlElementWrapper(name = "alternativeTitles")
	@XmlElements({ @XmlElement(name = "alternativeTitle", type = String.class) })
	public List<String> getAlternativeTitles() {
		return alternativeTitles;
	}

	/**
	 * @param alternativeTitles d. {@link #alternativeTitles}, d. gesetzt werden
	 *                          soll als {@link List<String>}.
	 * 
	 * @see eu.gronos.kostenrechner.interfaces.Vorsorgend#setAlternativeTitles(java.util.List)
	 */
	@Override
	public void setAlternativeTitles(List<String> alternativeTitles) {
		this.alternativeTitles = new ArrayList<String>();// LinkedList
		for (String title : alternativeTitles) {
			this.alternativeTitles.add(super.deWhiteSpace(title));
		}
	}
	// alternativeTitles;

	/**
	 * Die Methode setzt einen Title aus den vorhandenen
	 * {@link #getAlternativeTitles()}. Danach muss applyTo() aufgerufen werden.
	 * 
	 * @param index der Index des neuen Titles
	 * @return die {@link VorsorgendeBeschriftung} mit dem neuen
	 *         {@link Beschriftung#getTitle()}
	 * 
	 * @see eu.gronos.kostenrechner.interfaces.Vorsorgend#changeTo(int)
	 */
	@Override
	public VorsorgendeBeschriftung changeTo(int index) {
		if (index > -1 && index < getAlternativeTitles().size()) {
			super.setTitle(getAlternativeTitles().get(index));
		} else {
			System.err.printf("Beschriftung nicht vorhanden: %d!%n", index);
		}
		return this;
	}
	// super.getTitle();

	@Override
	public Component applyTo(Component comp) throws IllegalArgumentException {
		// TODO Listeners?
		super.applyTo(comp);
		return comp;
	}

}
