/**
 * KostenTenorLadenSpeichern.java
 * eu.gronos.kostenrechner (Kostenrechner)
 */
package eu.gronos.kostenrechner.view;

import java.awt.Component;
import java.io.File;

import javax.swing.JFileChooser;
import javax.swing.filechooser.FileNameExtensionFilter;
import javax.xml.bind.JAXBException;

import eu.gronos.kostenrechner.Kostenrechner;
import eu.gronos.kostenrechner.controller.files.BerechnungXmlDatei;
import eu.gronos.kostenrechner.model.tenordaten.VerfahrensDatenContainer;
import eu.gronos.kostenrechner.view.helpanderror.FehlerDialog;

/**
 * Eine Klasse, die alle Zustände des Programms im XML-Format speichern kann.
 *
 * @author Peter Schuster (setrok)
 * @date 26.12.2014
 *
 * @url "http://java.kompf.de/jaxbjava.html"
 * @url "http://docs.oracle.com/javase/tutorial/jaxb/intro/"
 */
public class BerechnungFileChooser extends KostenFileChooser {

	private static final long serialVersionUID = 5816976530887334541L;
	static final FileNameExtensionFilter filter = new FileNameExtensionFilter(
			String.format("%s (%s)", BerechnungXmlDatei.DATEITYP, BerechnungXmlDatei.DATEIENDUNG),
			BerechnungXmlDatei.DATEIENDUNG);
	public BerechnungXmlDatei berechnungXml;

	/**
	 * Konstruktor ohne Parameter
	 * 
	 */
	public BerechnungFileChooser() {
		super(filter);
		berechnungXml = new BerechnungXmlDatei();
	}

	/**
	 * Die Methode dient dazu, einen Dateiauswahldialog der {@link JFileChooser
	 * Oberklasse} aufzurufen um dann mit
	 * {@link BerechnungXmlDatei#speicherXml(VerfahrensDatenContainer, File)} die
	 * übergebenen Programmzustände als XML zu speichern.
	 * 
	 * @param parent    die aufrufende {@link Component}
	 * @param container der {@link VerfahrensDatenContainer} mit allen zu
	 *                  speichernden Zuständen
	 * @return den Rückgabestatus des {@link JFileChooser}s:<br>
	 *         <ul>
	 *         <li>{@link JFileChooser#CANCEL_OPTION}</li>
	 *         <li>{@link JFileChooser#APPROVE_OPTION}</li>
	 *         <li>{@link JFileChooser#ERROR_OPTION}, wenn der Dialog einen Fehler
	 *         auslöst, er abgebrochen wird oder es einen Fehler beim Laden
	 *         gibt.</li>
	 * 
	 * @see JFileChooser#showSaveDialog(Component)
	 * @see JFileChooser#showDialog(Component, String)
	 */
	public int speicherXmlDialog(Component parent, VerfahrensDatenContainer container) {
		int option = super.showSaveDialog(parent);
		if (option == JFileChooser.APPROVE_OPTION)
			try {
				File datei = super.getSelectedFile();
				berechnungXml.speicherXml(container, datei);
				Kostenrechner.getLogger().info(String.format("Gespeichert: %s", datei.getAbsolutePath()));
			} catch (JAXBException je) {
				option = JFileChooser.ERROR_OPTION;
				FehlerDialog.zeigeFehler("Fehler beim Speichern als XML!", je);
			}
		return option;
	}
//				if (!datei.getName().endsWith(BerechnungXmlDatei.DATEIENDUNG_GANZ))
//					datei = new File(datei.getAbsolutePath() + BerechnungXmlDatei.DATEIENDUNG_GANZ);
//				container.allgemein.speicherdatum = VerfahrensDatenContainerUtil.speicherDatum();

	/**
	 * Die Methode dient dazu, einen Dateiauswahldialog der {@link JFileChooser
	 * Oberklasse} aufzurufen um dann mit {@link BerechnungXmlDatei#ladeXml(File)}
	 * aus der ausgewählte Datei einen {@link VerfahrensDatenContainer} auszulesen.
	 * 
	 * @param parent die aufrufende {@link Component}
	 * @return einen {@link VerfahrensDatenContainer} zum Auslesen
	 * 
	 * @see JFileChooser#showDialog(Component, String)
	 * @see javax.swing.JFileChooser#showOpenDialog(java.awt.Component)
	 */
	public VerfahrensDatenContainer ladeXmlDialog(Component parent) {
		VerfahrensDatenContainer container = null;
		int option = super.showOpenDialog(parent);
		if (option == JFileChooser.APPROVE_OPTION) {
			File datei = super.getSelectedFile();
			container = berechnungXml.ladeXml(datei);
		}
		return container;
	}

}
