/**
 * AktionenJMenu.java
 * eu.gronos.kostenrechner.view (Kostenrechner)
 */
package eu.gronos.kostenrechner.view;

import javax.swing.AbstractAction;
import javax.swing.Action;
import javax.swing.JMenu;

import eu.gronos.kostenrechner.Kostenrechner;
import eu.gronos.kostenrechner.controller.BeendenAction;
import eu.gronos.kostenrechner.controller.BeschriebeneAktion;
import eu.gronos.kostenrechner.controller.TabellenZuruecksetzenAction;
import eu.gronos.kostenrechner.controller.files.LadeSkktxAction;
import eu.gronos.kostenrechner.controller.files.SpeichereSkktxAction;
import eu.gronos.kostenrechner.model.LangBeschriftung;
import eu.gronos.kostenrechner.model.NameContainerSammlung;
import eu.gronos.kostenrechner.view.baumbach.StreitgenossenPanel;

/**
 * Das Menü Datei stellt die Aktionen für alle möglichen Dateioperationen zu
 * Menüpunkten zusammen.
 *
 * @author Peter Schuster (setrok)
 * @date 20.06.2018
 *
 */
public class DateiJMenu extends JMenu {

	private static final long serialVersionUID = 1481786221712533553L;
	private static final DateiJMenu instance = new DateiJMenu();
	private Kostenrechner kostenrechner;

	private final AbstractAction tabellenZuruecksetzenAction = new TabellenZuruecksetzenAction(
			(LangBeschriftung) NameContainerSammlung.BESCHRIFTUNGEN.get(61011));
	private Action skktxLaden = new LadeSkktxAction(getKostenrechner(),
			(LangBeschriftung) NameContainerSammlung.BESCHRIFTUNGEN.get(61021));
	private Action skktxSpeichern = new SpeichereSkktxAction(this,
			(LangBeschriftung) NameContainerSammlung.BESCHRIFTUNGEN.get(61041));
	AbstractAction beendenAction = new BeendenAction(
			(LangBeschriftung) NameContainerSammlung.BESCHRIFTUNGEN.get(61091));

	/**
	 * Der private Konstruktor hat keine Parameter
	 * 
	 */
	private DateiJMenu() {
		super();
	}

	/**
	 * Die Methode dient dazu, das Dateimenü zusammenzubauen.
	 * 
	 */
	public void buildMenu() {
		NameContainerSammlung.BESCHRIFTUNGEN.get(61000).applyTo(this);
		// TODO Tastenkürzel doppelt?
		add(((BeschriebeneAktion) tabellenZuruecksetzenAction).toMenuItem());
		add(((BeschriebeneAktion) skktxLaden).toMenuItem());
		add(((BeschriebeneAktion) StreitgenossenPanel.getInstance().xmlLesenAction).toMenuItem());
		add(((BeschriebeneAktion) skktxSpeichern).toMenuItem());
		addSeparator();
		add(((BeschriebeneAktion) beendenAction).toMenuItem());
	}

	/**
	 * @return gibt {@link #instance} als AktionenJMenu zurück.
	 */
	public static DateiJMenu getInstance() {
		return instance;
	}

	/**
	 * @param kostenrechner d. {@link #kostenrechner}, d. gesetzt werden soll als
	 *                      Kostenrechner
	 */
	public void setKostenrechner(Kostenrechner kostenrechner) {
		this.kostenrechner = kostenrechner;
	}

	/**
	 * @return gibt {@link #kostenrechner} als Kostenrechner zurück.
	 */
	public Kostenrechner getKostenrechner() {
		return kostenrechner;
	}

}

// , KeyEvent.VK_F, KeyStroke.getKeyStroke(KeyEvent.VK_O,
// Kostenrechner.ctrlMask)
//,KeyEvent.VK_E, KeyEvent.VK_Z,
// KeyStroke.getKeyStroke(KeyEvent.VK_N, Kostenrechner.ctrlMask)
//, KeyEvent.VK_S, KeyStroke.getKeyStroke(KeyEvent.VK_S, Kostenrechner.ctrlMask)
//			"Neu / Alle Einträge zurücksetzen","neue-berechnung", 
//			"Leert die Tabelle der Gebührentatbestände und die Tabellen der Beteiligten", 
//			"Ende", "Beendet Kostentenor", "quit"
//			"Berechnung speichern",
//			"Speichert die Daten aller Registerkarten für spätere Berechnungen ab", "save",
// "Berechnung öffnen","open","Lädt die Daten aller Registerkarten aus einer
// früher gespeicherten Berechnung",
// "Datei"
// setMnemonic(KeyEvent.VK_D);
// new JMenuItem(tabellenZuruecksetzenAction));
// new JMenuItem(skktxLaden));
// new JMenuItem(StreitgenossenPanel.getInstance().xmlLesenAction));
// new JMenuItem(skktxSpeichern));
// new JMenuItem(beendenAction));
